# PyRoll CLI

This is a command line interface (CLI) for the rollig simulation framework PyRolL.
See the [core repository](https://github.com/pyroll-project/pyroll-core) for further information.

## Documentation

See the [documentation](https://pyroll.readthedocs.io/en/latest/basic/cli.html) to learn about basic concepts and
usage.

## License

The project is licensed under the [BSD 3-Clause license](LICENSE).
